# Pinpoint - Base Theme 
This is a base theme for Magento 2 designed and developed by Pinpoint.

## What is it? 
The Pinpoint Base Theme is a SCSS based theme for Magento 2 that should be used as a starting point for internal builds. It includes basic customisation of most common elements that are used across the majority of sites, commonly used Javascript etc.

It was built to be used as a parent theme and should not be edited or modified within a client project. Instead, a child theme should be used when utilising this theme. It has been built to be fully customisable from within the child theme.

## Requirements
* Magento 2.4.5-p1
* [Pinpoint Frontend Toolkit](https://github.com/PinpointDesigns/pinpoint-frontend-toolkit)
* [Pinpoint Theme Options (Module)](https://github.com/PinpointDesigns/pinpoint_themeoptions)

## Installation

### For Development

#### Clone The Repository

Clone this repository to a Magento site (must be running v2.4.5-p1 or higher) within the `app/design/frontend/Pinpoint/base-theme` directory

* `cd app/design/frontend`
* `mkdir Pinpoint/base-theme`
* `cd Pinpoint/base-theme`
* `git clone git@github.com:PinpointDesigns/pinpoint-base-theme.git .`
  
#### Install the npm packages

* `nvm use`
* `npm install`

### For Usage

#### Install via composer

*(This part has not been done yet, but the steps below are the expected steps that would be required to instlal this theme on a client site that hasn't been built from the boilerplate)*
* Run `composer require pinpoint/base-theme`
* Add theme details to the Frontend-Toolkits `config/themes.json`

#### Install the npm packages
*This is something we haven't worked on yet, and will need to be put in place somehow before we start installing via composer.*


## Usage (with child theme)
* Create a child theme, a starter theme is available at [https://github.com/PinpointDesigns/child-theme](https://github.com/PinpointDesigns/child-theme)
* Add child theme to the Frontend-Toolkits `config/themes.json`, and declare the parent theme within there. See example below;
```
"child-theme": {
    "src": "app/design/frontend/pinpoint/child-theme",
    "dest": "pub/static/frontend/Pinpoint/child-theme",
    "locale": ["en_GB"],
    "parent": "base-theme",
    "includePaths": ["../../../app/design/frontend/pinpoint/base-theme/node_modules","../../../app/design/frontend/pinpoint/child-theme/node_modules"]
  }
```
* Enable the child theme within the Magento admin panel `Content > Design > Configuration`
* Make your customisation in the child theme. For more information about this please see the `README.md` within the child theme.

## SCSS Directory Structure

The base-theme follows a specific folder structure:

* `/settings`: Global variables, site-wide settings, config switches, etc.
* `/tools`: Site-wide mixins and functions.
* `/generic`: Low-specificity, far-reaching rulesets (e.g. resets).
* `/elements`: Unclassed HTML elements (e.g. `a {}`, `blockquote {}`, `address {}`).
* `/ui`: UI Elements brought over from Spirit
* `/components`: Discrete, complete chunks of UI (e.g. `.c-carousel {}`).
* `/pages`: Page specific CSS brought over from Spirit, we should look at reducing some of this at a point in the future.
* `/utilities`: High-specificity, very explicit selectors. Overrides and helper
  classes (e.g. `.u-hidden {}`).


## 503 Page
To install the themed 503 page, please copy the `errors/base-theme` folder to `/pub/errors` and change the `local.xml` file to read:
```<skin>base-theme</skin>```
